@@ -2,7 +2,7 @@ from typing import Literal, Optional, Any, Dict
 
 from pydantic import BaseModel
 
-class QueryShema(BaseModel):
+class CommonQueryShema(BaseModel):
     pagesize: Optional[int] = 20
     pagenum: Optional[int] = 1
     filter: Dict = None
