@@ -21,7 +21,7 @@ class XTJsonResponse(JSONResponse):
         return toBytesJson(content,self.striplang)
 
 from .cache import cache
-from .CommonResponse import CommonResponse,QueryShema
+from .CommonResponse import CommonResponse,CommonQueryShema
 from .CommonError import Common500Response,TokenException,PermissionException
 from .snowFlakeId import snowFlack
 from .encrypt import generateKey
