@@ -1,11 +1,10 @@
-from sqlalchemy.orm import DeclarativeMeta
 from pydantic import BaseModel
 from decimal import Decimal
 from typing import Any
 import orjson
 from sqlalchemy.engine import RowMapping
 def obj2dict(obj:Any,striplang='')->Any:#type: ignore
-    if isinstance(obj,DeclarativeMeta):
+    if hasattr(obj,'__tablename__'):
         return obj.dict(striplang=striplang)
     elif isinstance(obj,BaseModel):
         return obj.dict()
